@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (C) 2012, 2016-2017 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2012-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 import matplotlib.pyplot as plt
 import numpy
@@ -34,9 +34,9 @@ alloy.x = 1.
 [qxt1, qzt1] = alloy.RelaxationTriangle([2, 2, 4], substrate, hxrd001)
 
 plt.figure()
-plt.plot(qxt0, qzt0, 'r-')
-plt.plot(qxt1, qzt1, 'b-')
-plt.plot(qinp, qout, 'ko')
+plt.plot(qxt0, qzt0, '-r')
+plt.plot(qxt1, qzt1, '-b')
+plt.plot(qinp, qout, 'ok')
 
 # print concentration of alloy B calculated from a reciprocal space point
 print(alloy.ContentBasym(qinp, qout, [2, 2, 4], [0, 0, 1]))
