@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (C) 2012-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2012-2021 Dominik Kriegner <dominik.kriegner@gmail.com>
 """
 module with a function wrapper to scipy.optimize.leastsq
 for fitting of a 2D function to a peak or a 1D Gauss fit with
@@ -650,7 +650,7 @@ def multPeakFit(x, data, peakpos, peakwidth, dranges=None,
         if fit.stopreason[0] not in ['Sum of squares convergence']:
             print("XU.math.multPeakFit: fit NOT converged (%s)"
                   % fit.stopreason[0])
-            return Nono, None, None, None
+            return None, None, None, None
     except IndexError:
         print("XU.math.multPeakFit: fit most probably NOT converged (%s)"
               % str(fit.stopreason))
