@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-# Copyright (C) 2015-2020 Dominik Kriegner <dominik.kriegner@gmail.com>
+# Copyright (C) 2014-2021 Dominik Kriegner <dominik.kriegner@gmail.com>
 
 """
 Module provides functions to convert a q-vector from reciprocal space to
@@ -59,7 +59,7 @@ def _makebounds(boundsin):
         bounds to be handed over to the scipy.minimize routine. The function
         will expand fixed values to two equal bounds
     constraints, list
-        list of equivility constraints for fixed values
+        list of equality constraints for fixed values
     """
     lb = []
     ub = []
@@ -70,31 +70,37 @@ def _makebounds(boundsin):
                 lb.append(b[0])
                 ub.append(b[1])
             elif len(b) == 1:
-                # due to a bug in scipy >= 1.5.0 we need to allow a small
-                # variation
-                lb.append(b[0] - config.EPSILON)
-                ub.append(b[0] + config.EPSILON)
-                # to really fix the parameter we create an equivalent
-                # constraint; see scipy/scipy#12433
-                constraints.append(dict(type='eq',
-                                        fun=lambda x, j=j, v=b[0]: x[j] - v,
-                                        # lambda j=j to bind variable by value
-                                        ))
+                # upper = lower bound needs equality constraint in scipy<1.8.0
+                if tuple(map(int, scipy.__version__.split('.')[:2])) > (1, 8):
+                    lb.append(b[0])
+                    ub.append(b[0])
+                else:
+                    lb.append(-numpy.inf)
+                    ub.append(numpy.inf)
+                    # see scipy/scipy#12433
+                    constraints.append(
+                        dict(type='eq',
+                             fun=lambda x, j=j, v=b[0]: x[j] - v,
+                             # lambda j=j to bind var. by value
+                             ))
             else:
                 raise InputError('bound values must have two or one elements')
         elif isinstance(b, numbers.Number):
-            # due to a bug in scipy >= 1.5.0 we need to allow a small variation
-            lb.append(b - config.EPSILON)
-            ub.append(b + config.EPSILON)
-            # to really fix the parameter we create an equivalent
-            # constraint; see scipy/scipy#12433
-            constraints.append(dict(type='eq',
-                                    fun=lambda x, j=j, v=b: x[j] - v,
-                                    # lambda j=j to bind variable by value
-                                    ))
+            # upper = lower bound needs equality constraint in scipy<1.8.0
+            if tuple(map(int, scipy.__version__.split('.')[:2])) > (1, 8):
+                lb.append(b)
+                ub.append(b)
+            else:
+                lb.append(-numpy.inf)
+                ub.append(numpy.inf)
+                # see scipy/scipy#12433
+                constraints.append(dict(type='eq',
+                                        fun=lambda x, j=j, v=b: x[j] - v,
+                                        # lambda j=j to bind var. by value
+                                        ))
         elif b is None:
-            lb.append(-np.inf)
-            ub.append(np.inf)
+            lb.append(-numpy.inf)
+            ub.append(numpy.inf)
         else:
             raise InputError('bound value is of invalid type (%s)' % type(b))
 
